@@ -4,10 +4,10 @@ from pathlib import Path
 from shutil import copytree, rmtree
 
 LAYERS_VERSIONS = '1.0.0'
-PACKAGE_NAME = 'pet-layers'
+PACKAGE_NAME = 'layers'
 
 README = '''
-# Pet layers
+# layers
 ***
 
 '''
